@@ -35,6 +35,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <stdlib.h>
 #include <string.h>
 
 #define EOG_THUMB_VIEW_SPACING 0
@@ -870,7 +871,7 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 
 /**
  * eog_thumb_view_set_thumbnail_popup:
- * @thumbview: A #GtkThumbView.
+ * @thumbview: An #EogThumbView.
  * @menu: A #GtkMenu.
  *
  * Set the contextual menu to be used with the thumbnails in the
